==> ext-system-test-0.8.1.1-sources.jar: org/bluestemsoftware/open/eoa/test/system/policy/WSPolicyFactoryProvider.java <==
/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.test.system.policy;

import java.lang.reflect.Method;

import javax.xml.transform.Source;

import org.bluestemsoftware.open.eoa.test.system.util.MockExtensionProviderFactory;
import org.bluestemsoftware.specification.eoa.ext.ExtensionException;
import org.bluestemsoftware.specification.eoa.ext.policy.wsp15.WSPolicyDocument;
import org.bluestemsoftware.specification.eoa.ext.policy.wsp15.WSPolicyException;
import org.bluestemsoftware.specification.eoa.ext.policy.wsp15.WSPolicyFactory;
import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;

public class WSPolicyFactoryProvider implements WSPolicyFactory.Provider {

    public static final String NAME = "ws-policy-test";

    protected MockExtensionProviderFactory mockExtensionProviderFactory;

    public WSPolicyFactoryProvider(MockExtensionProviderFactory mockExtensionProviderFactory) {
        super();
        this.mockExtensionProviderFactory = mockExtensionProviderFactory;
    }
    
    public MockExtensionProviderFactory getMockExtensionProviderFactory() {
        return mockExtensionProviderFactory;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory$Provider#spi_getName()
     */
    public String spi_getName() {
        return NAME;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory$Provider#spi_getExtensionType()
     */
    public String spi_getExtensionType() {
        return WSPolicyDocument.TYPE;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.policy.wsp15.WSPolicyFactory$Provider#spi_dereferenceLocation(org.xml.sax.EntityResolver, java.lang.String)
     */
    public InputSource spi_dereferenceLocation(EntityResolver entityResolver, String location) throws WSPolicyException {
        throw new UnsupportedOperationException("not mockable");
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.policy.wsp15.WSPolicyFactory$Provider#spi_readPolicy(org.xml.sax.EntityResolver, javax.xml.transform.Source)
     */
    public WSPolicyDocument spi_readPolicy(EntityResolver entityResolver, Source source) throws WSPolicyException {
        Class<?>[] signature = new Class[] {EntityResolver.class, Source.class};
        Method method = null;
        try {
            method = WSPolicyFactory.Provider.class.getMethod("spi_readPolicy", signature);
        } catch (Exception fatchance) {
        }
        Object[] args = new Object[] {entityResolver, source};
        try {
            return (WSPolicyDocument)mockExtensionProviderFactory.createExtensionProvider(method, args);
        } catch (ExtensionException ex) {
            throw new WSPolicyException(ex);
        }
    }

}

==> ext-system-test-0.8.5.0-sources.jar: org/bluestemsoftware/open/eoa/test/system/policy/WSPolicyFactoryProvider.java <==
/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.test.system.policy;

import java.lang.reflect.Method;

import javax.xml.transform.Source;

import org.bluestemsoftware.open.eoa.test.system.dependency.FactoryDependencyImpl;
import org.bluestemsoftware.open.eoa.test.system.util.MockExtensionProviderFactory;
import org.bluestemsoftware.specification.eoa.ext.ExtensionException;
import org.bluestemsoftware.specification.eoa.ext.policy.wsp15.WSPolicyDocument;
import org.bluestemsoftware.specification.eoa.ext.policy.wsp15.WSPolicyException;
import org.bluestemsoftware.specification.eoa.ext.policy.wsp15.WSPolicyFactory;
import org.xml.sax.EntityResolver;
import org.xml.sax.InputSource;

/**
 * Wraps a user provided instance of {@link MockExtensionProviderFactory} which
 * facilitates the creation of mock/stubbed instances of {@link WSPolicyDocument.Provider}
 * used within the context of a test.  See documentation for usage examples.
 * 
 * @see FactoryDependencyImpl
 */

public class WSPolicyFactoryProvider implements WSPolicyFactory.Provider {

    public static final String NAME = "ws-policy-test";

    protected MockExtensionProviderFactory mockExtensionProviderFactory;

    public WSPolicyFactoryProvider(MockExtensionProviderFactory mockExtensionProviderFactory) {
        super();
        this.mockExtensionProviderFactory = mockExtensionProviderFactory;
    }
    
    public MockExtensionProviderFactory getMockExtensionProviderFactory() {
        return mockExtensionProviderFactory;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory$Provider#spi_getName()
     */
    public String spi_getName() {
        return NAME;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory$Provider#spi_getExtensionType()
     */
    public String spi_getExtensionType() {
        return WSPolicyDocument.TYPE;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.policy.wsp15.WSPolicyFactory$Provider#spi_dereferenceLocation(org.xml.sax.EntityResolver, java.lang.String)
     */
    public InputSource spi_dereferenceLocation(EntityResolver entityResolver, String location) throws WSPolicyException {
        throw new UnsupportedOperationException("not mockable");
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.policy.wsp15.WSPolicyFactory$Provider#spi_readPolicy(org.xml.sax.EntityResolver, javax.xml.transform.Source)
     */
    public WSPolicyDocument spi_readPolicy(EntityResolver entityResolver, Source source) throws WSPolicyException {
        Class<?>[] signature = new Class[] {EntityResolver.class, Source.class};
        Method method = null;
        try {
            method = WSPolicyFactory.Provider.class.getMethod("spi_readPolicy", signature);
        } catch (Exception fatchance) {
        }
        Object[] args = new Object[] {entityResolver, source};
        try {
            return (WSPolicyDocument)mockExtensionProviderFactory.createExtensionProvider(method, args);
        } catch (ExtensionException ex) {
            throw new WSPolicyException(ex);
        }
    }

}
